@@ -7,7 +7,7 @@ RTF::Tokenizer - Tokenize RTF
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 DESCRIPTION
 
@@ -55,11 +55,12 @@ require 5;
 
 package RTF::Tokenizer;
 BEGIN {
-  $RTF::Tokenizer::VERSION = '1.12';
+  $RTF::Tokenizer::VERSION = '1.13';
 }
 use vars qw($VERSION);
 
 use strict;
+use warnings;
 use Carp;
 use IO::File;
 
@@ -317,13 +318,13 @@ sub get_token {
 			# We want to return text fields that have newlines in as one
 			# token, which requires a bit of work, as we read in one line
 			# at a time from out files...
-			my $temp_text;
+			my $temp_text = '';
 
 		READTEXT:
 
 			# Grab all the next 'text' characters
 			$self->{_BUFFER} =~ s/^([^\\{}]+)//s;
-			$temp_text .= $1;
+			$temp_text .= $1 if defined $1;
 
 			# If the buffer is empty, try reading in some more, and
 			# then go back to READTEXT to keep going. Now, the clever
